==> urwidgets-0.1.1.tar.gz: urwidgets-0.1.1/README.md <==
# urWIDgets

A collection of widgets for [urwid](https://urwid.org)

## Contents
- [Installation](#installation)
- [Usage](#usage)
- [Contribution](#contribution)
- [Donate](#donate)


## Installation

### Requirements
- [Python](https://www.python.org/) >= 3.7
- [urwid](https://github.com/urwid/urwid/wiki/Installation-instructions) (will be installed automatically)

### Steps
The latest **stable** version can be installed from [PyPI](https://pypi.org/project/urwidgets) with:

```shell
pip install urwidgets
```

The **development** version can be installed with:

```shell
pip install git+https://github.com/AnonymouX47/urwidgets.git
```


## Usage

<p align="center"><b>
   🚧 There might be incompatible changes between minor versions of
   <a href='https://semver.org/spec/v2.0.0.html#spec-item-4'>version zero</a>!
</b></p>

**If you want to use this library in a project while it's still on version zero, ensure you pin the dependency to a specific minor version e.g `>=0.1,<0.2`.**

See the [docs](https://urwidgets.readthedocs.io) for the API Reference.


## Contribution

Please read through the [guidelines](https://github.com/AnonymouX47/urwidgets/blob/main/CONTRIBUTING.md).


## Donate

<a href="https://www.buymeacoffee.com/anonymoux47" target="_blank">
  <img src="https://cdn.buymeacoffee.com/buttons/v2/default-yellow.png" alt="Buy Me A Coffee" style="height: 60px !important;width: 217px !important;" >
</a>

Your donation will go a long way in aiding the progress and development of this project.
Thank you! 💓

==> urwidgets-0.2.1.tar.gz: urwidgets-0.2.1/README.md <==
# urWIDgets

A collection of widgets for [urwid](https://urwid.org)

## Contents
- [Installation](#installation)
- [Usage](#usage)
- [Contribution](#contribution)
- [Sponsor This Project](#sponsor-this-project)


## Installation

### Requirements
- [Python](https://www.python.org/) >= 3.7
- [urwid](https://github.com/urwid/urwid/wiki/Installation-instructions) (will be installed automatically)

### Steps
The latest **stable** version can be installed from [PyPI](https://pypi.org/project/urwidgets) with:

```shell
pip install urwidgets
```

The **development** version can be installed with:

```shell
pip install git+https://github.com/AnonymouX47/urwidgets.git
```


## Usage

<p align="center"><b>
   🚧 There might be incompatible changes between minor versions of
   <a href='https://semver.org/spec/v2.0.0.html#spec-item-4'>version zero</a>!
</b></p>

**If you want to use this library in a project while it's still on version zero, ensure you pin the dependency to a specific minor version e.g `>=0.1,<0.2`.**

See the [docs](https://urwidgets.readthedocs.io) for the API Reference (with usage examples).

## Contribution

Please read through the [guidelines](https://github.com/AnonymouX47/urwidgets/blob/main/CONTRIBUTING.md).

## Sponsor This Project

<a href="https://www.buymeacoffee.com/anonymoux47" target="_blank">
  <img src="https://cdn.buymeacoffee.com/buttons/v2/default-yellow.png" alt="Buy Me A Coffee" style="height: 60px !important;width: 217px !important;" >
</a>

Any amount will go a long way in aiding the progress and development of this project.
Thank you! 💓
